from __future__ import annotations

from datetime import datetime
from typing import TYPE_CHECKING, List, Optional, Union, Any

if TYPE_CHECKING:
    from ..client import SyncPhraseTMSClient

from ..models import (
    ImportSettingsDto,
    PageDtoImportSettingsReference,
    ImportSettingsEditDto,
    ImportSettingsCreateDto
    
)


class ImportsettingsOperations:
    def __init__(self, client: SyncPhraseTMSClient):
        self.client = client


    def create_import_settings(
        self,
        import_settings_create_dto: ImportSettingsCreateDto,
        phrase_token: Optional[str] = None,
) -> ImportSettingsDto:
        """
        Operation id: createImportSettings
        Create import settings
        Pre-defined import settings is handy for [Create Job](#operation/createJob).
                  See [supported file types](https://wiki.memsource.com/wiki/API_File_Type_List)
        :param import_settings_create_dto: ImportSettingsCreateDto (required), body. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ImportSettingsDto
        """
        endpoint = f"/api2/v1/importSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = import_settings_create_dto

        r = self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ImportSettingsDto(**r.json())
        


    def delete_import_settings(
        self,
        uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: deleteImportSettings
        Delete import settings
        
        :param uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/importSettings/{uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "DELETE",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    def edit_default_import_settings(
        self,
        import_settings_edit_dto: ImportSettingsEditDto,
        phrase_token: Optional[str] = None,
) -> ImportSettingsDto:
        """
        Operation id: editDefaultImportSettings
        Edit organization's default import settings
        
        :param import_settings_edit_dto: ImportSettingsEditDto (required), body. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ImportSettingsDto
        """
        endpoint = f"/api2/v1/importSettings/default"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = import_settings_edit_dto

        r = self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ImportSettingsDto(**r.json())
        


    def edit_import_settings(
        self,
        import_settings_edit_dto: ImportSettingsEditDto,
        phrase_token: Optional[str] = None,
) -> ImportSettingsDto:
        """
        Operation id: editImportSettings
        Edit import settings
        
        :param import_settings_edit_dto: ImportSettingsEditDto (required), body. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ImportSettingsDto
        """
        endpoint = f"/api2/v1/importSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = import_settings_edit_dto

        r = self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ImportSettingsDto(**r.json())
        


    def get_import_settings_by_uid(
        self,
        uid: str,
        phrase_token: Optional[str] = None,
) -> ImportSettingsDto:
        """
        Operation id: getImportSettingsByUid
        Get import settings
        
        :param uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ImportSettingsDto
        """
        endpoint = f"/api2/v1/importSettings/{uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ImportSettingsDto(**r.json())
        


    def get_import_settings_default(
        self,
        phrase_token: Optional[str] = None,
) -> ImportSettingsDto:
        """
        Operation id: getImportSettingsDefault
        Get organization's default import settings
        
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ImportSettingsDto
        """
        endpoint = f"/api2/v1/importSettings/default"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ImportSettingsDto(**r.json())
        


    def list_import_settings(
        self,
        name: Optional[str] = None,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 50,
        phrase_token: Optional[str] = None,
) -> PageDtoImportSettingsReference:
        """
        Operation id: listImportSettings
        List import settings
        
        :param name: Optional[str] = None (optional), query. 
        :param page_number: Optional[int] = 0 (optional), query. Page number, starting with 0, default 0.
        :param page_size: Optional[int] = 50 (optional), query. Page size, accepts values between 1 and 50, default 50.
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoImportSettingsReference
        """
        endpoint = f"/api2/v1/importSettings"
        params = {
            "name": name,
            "pageNumber": page_number,
            "pageSize": page_size
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoImportSettingsReference(**r.json())
        



if __name__ == '__main__':
    print("This module is not intended to be run directly.")


from __future__ import annotations

from datetime import datetime
from typing import TYPE_CHECKING, List, Optional, Union, Any

if TYPE_CHECKING:
    from ..client import SyncPhraseTMSClient

from ..models import (
    PageDtoMemsourceTranslateProfileDto
    
)


class LanguageAIOperations:
    def __init__(self, client: SyncPhraseTMSClient):
        self.client = client


    def list_memsource_translate_profile(
        self,
        include_projects: Optional[bool] = True,
        name: Optional[str] = None,
        order: Optional[str] = "desc",
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 10,
        sort: Optional[str] = "name",
        phrase_token: Optional[str] = None,
) -> PageDtoMemsourceTranslateProfileDto:
        """
        Operation id: listMemsourceTranslateProfile
        List of Language AI profiles
        
        :param include_projects: Optional[bool] = True (optional), query. 
        :param name: Optional[str] = None (optional), query. Filter by name.
        :param order: Optional[str] = "desc" (optional), query. desc.
        :param page_number: Optional[int] = 0 (optional), query. Page number, starting with 0, default 0.
        :param page_size: Optional[int] = 10 (optional), query. Page size, accepts values between 1 and 50, default 10.
        :param sort: Optional[str] = "name" (optional), query. Sort by.
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoMemsourceTranslateProfileDto
        """
        endpoint = f"/api2/v1/memsourceTranslateProfiles"
        params = {
            "name": name,
            "sort": sort,
            "order": order,
            "pageNumber": page_number,
            "pageSize": page_size,
            "includeProjects": include_projects
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoMemsourceTranslateProfileDto(**r.json())
        



if __name__ == '__main__':
    print("This module is not intended to be run directly.")


from __future__ import annotations

from datetime import datetime
from typing import TYPE_CHECKING, List, Optional, Union, Any

if TYPE_CHECKING:
    from ..client import SyncPhraseTMSClient

from ..models import (
    PageDtoTranslationPriceListDto,
    TranslationPriceSetBulkDeleteDto,
    PageDtoTranslationPriceSetDto,
    TranslationPriceSetBulkMinimumPricesDto,
    TranslationPriceListDto,
    TranslationPriceListCreateDto,
    TranslationPriceSetListDto,
    TranslationPriceSetBulkPricesDto,
    TranslationPriceSetCreateDto
    
)


class PriceListOperations:
    def __init__(self, client: SyncPhraseTMSClient):
        self.client = client


    async def create_language_pair(
        self,
        translation_price_set_create_dto: TranslationPriceSetCreateDto,
        price_list_uid: str,
        phrase_token: Optional[str] = None,
) -> TranslationPriceSetListDto:
        """
        Operation id: createLanguagePair
        Add language pairs
        
        :param translation_price_set_create_dto: TranslationPriceSetCreateDto (required), body. 
        :param price_list_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: TranslationPriceSetListDto
        """
        endpoint = f"/api2/v1/priceLists/{price_list_uid}/priceSets"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = translation_price_set_create_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return TranslationPriceSetListDto(**r.json())
        


    async def create_price_list(
        self,
        translation_price_list_create_dto: TranslationPriceListCreateDto,
        phrase_token: Optional[str] = None,
) -> TranslationPriceListDto:
        """
        Operation id: createPriceList
        Create price list
        
        :param translation_price_list_create_dto: TranslationPriceListCreateDto (required), body. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: TranslationPriceListDto
        """
        endpoint = f"/api2/v1/priceLists"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = translation_price_list_create_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return TranslationPriceListDto(**r.json())
        


    async def delete_language_pair(
        self,
        price_list_uid: str,
        source_language: str,
        target_language: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: deleteLanguagePair
        Remove language pair
        
        :param price_list_uid: str (required), path. 
        :param source_language: str (required), path. 
        :param target_language: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/priceLists/{price_list_uid}/priceSets/{source_language}/{target_language}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "DELETE",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    async def delete_language_pairs(
        self,
        translation_price_set_bulk_delete_dto: TranslationPriceSetBulkDeleteDto,
        price_list_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: deleteLanguagePairs
        Remove language pairs
        
        :param translation_price_set_bulk_delete_dto: TranslationPriceSetBulkDeleteDto (required), body. 
        :param price_list_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/priceLists/{price_list_uid}/priceSets"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = translation_price_set_bulk_delete_dto

        r = await self.client.make_request(
            "DELETE",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    async def delete_price_list(
        self,
        price_list_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: deletePriceList
        Delete price list
        
        :param price_list_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/priceLists/{price_list_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "DELETE",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    async def get_list_of_price_list(
        self,
        name: Optional[str] = None,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 50,
        phrase_token: Optional[str] = None,
) -> PageDtoTranslationPriceListDto:
        """
        Operation id: getListOfPriceList
        List price lists
        
        :param name: Optional[str] = None (optional), query. Filter for name.
        :param page_number: Optional[int] = 0 (optional), query. Page number, starting with 0, default 0.
        :param page_size: Optional[int] = 50 (optional), query. Page size, accepts values between 1 and 50, default 50.
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoTranslationPriceListDto
        """
        endpoint = f"/api2/v1/priceLists"
        params = {
            "pageNumber": page_number,
            "pageSize": page_size,
            "name": name
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoTranslationPriceListDto(**r.json())
        


    async def get_price_list(
        self,
        price_list_uid: str,
        phrase_token: Optional[str] = None,
) -> TranslationPriceListDto:
        """
        Operation id: getPriceList
        Get price list
        
        :param price_list_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: TranslationPriceListDto
        """
        endpoint = f"/api2/v1/priceLists/{price_list_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return TranslationPriceListDto(**r.json())
        


    async def get_prices_with_workflow_steps(
        self,
        price_list_uid: str,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 50,
        source_languages: Optional[List[str]] = None,
        target_languages: Optional[List[str]] = None,
        phrase_token: Optional[str] = None,
) -> PageDtoTranslationPriceSetDto:
        """
        Operation id: getPricesWithWorkflowSteps
        List price sets
        
        :param price_list_uid: str (required), path. 
        :param page_number: Optional[int] = 0 (optional), query. Page number, starting with 0, default 0.
        :param page_size: Optional[int] = 50 (optional), query. Page size, accepts values between 1 and 50, default 50.
        :param source_languages: Optional[List[str]] = None (optional), query. 
        :param target_languages: Optional[List[str]] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoTranslationPriceSetDto
        """
        endpoint = f"/api2/v1/priceLists/{price_list_uid}/priceSets"
        params = {
            "pageNumber": page_number,
            "pageSize": page_size,
            "sourceLanguages": source_languages,
            "targetLanguages": target_languages
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoTranslationPriceSetDto(**r.json())
        


    async def set_minimum_price_for_set(
        self,
        translation_price_set_bulk_minimum_prices_dto: TranslationPriceSetBulkMinimumPricesDto,
        price_list_uid: str,
        phrase_token: Optional[str] = None,
) -> TranslationPriceListDto:
        """
        Operation id: setMinimumPriceForSet
        Edit minimum prices
        
        :param translation_price_set_bulk_minimum_prices_dto: TranslationPriceSetBulkMinimumPricesDto (required), body. 
        :param price_list_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: TranslationPriceListDto
        """
        endpoint = f"/api2/v1/priceLists/{price_list_uid}/priceSets/minimumPrices"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = translation_price_set_bulk_minimum_prices_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return TranslationPriceListDto(**r.json())
        


    async def set_prices(
        self,
        translation_price_set_bulk_prices_dto: TranslationPriceSetBulkPricesDto,
        price_list_uid: str,
        phrase_token: Optional[str] = None,
) -> TranslationPriceListDto:
        """
        Operation id: setPrices
        Edit prices
        If object contains only price, all languages and workflow steps will be updated
        :param translation_price_set_bulk_prices_dto: TranslationPriceSetBulkPricesDto (required), body. 
        :param price_list_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: TranslationPriceListDto
        """
        endpoint = f"/api2/v1/priceLists/{price_list_uid}/priceSets/prices"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = translation_price_set_bulk_prices_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return TranslationPriceListDto(**r.json())
        


    async def update_price_list(
        self,
        translation_price_list_create_dto: TranslationPriceListCreateDto,
        price_list_uid: str,
        phrase_token: Optional[str] = None,
) -> TranslationPriceListDto:
        """
        Operation id: updatePriceList
        Update price list
        
        :param translation_price_list_create_dto: TranslationPriceListCreateDto (required), body. 
        :param price_list_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: TranslationPriceListDto
        """
        endpoint = f"/api2/v1/priceLists/{price_list_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = translation_price_list_create_dto

        r = await self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return TranslationPriceListDto(**r.json())
        



if __name__ == '__main__':
    print("This module is not intended to be run directly.")


from __future__ import annotations

from datetime import datetime
from typing import TYPE_CHECKING, List, Optional, Union, Any

if TYPE_CHECKING:
    from ..client import SyncPhraseTMSClient

from ..models import (
    EditQASettingsDtoV2,
    FileImportSettingsDto,
    SetProjectTemplateTermBaseDto,
    AsyncRequestWrapperV2Dto,
    ProjectTemplateTermBaseListDto,
    EditProjectSecuritySettingsDtoV2,
    PageDtoProjectTemplateReference,
    UpdateCustomFieldInstancesDto,
    AbstractProjectDtoV2,
    MTSettingsPerLanguageListDto,
    ProjectTemplateEditDto,
    PageDtoCustomFieldInstanceDto,
    CustomFieldInstanceDto,
    CreateCustomFieldInstancesDto,
    CreateProjectFromTemplateV2Dto,
    QASettingsDtoV2,
    ProjectTemplateTransMemoryListV2Dto,
    ProjectTemplateTransMemoryListDtoV3,
    EditAnalyseSettingsDto,
    AssignableTemplatesDto,
    ProjectTemplateEditV2Dto,
    PageDtoTransMemoryDto,
    JobPartReferences,
    CreateProjectFromTemplateAsyncV2Dto,
    PreTranslateSettingsV4Dto,
    ProjectTemplate,
    JobPartsDto,
    ProjectTemplateCreateActionDto,
    FileImportSettingsCreateDto,
    SetProjectTemplateTransMemoriesV2Dto,
    AbstractAnalyseSettingsDto,
    ProjectSecuritySettingsDtoV2,
    CustomFieldInstancesDto,
    UpdateCustomFieldInstanceDto
    
)


class ProjectTemplateOperations:
    def __init__(self, client: SyncPhraseTMSClient):
        self.client = client


    async def assign_linguists_from_template(
        self,
        project_uid: str,
        template_uid: str,
        phrase_token: Optional[str] = None,
) -> JobPartsDto:
        """
        Operation id: assignLinguistsFromTemplate
        Assigns providers from template
        
        :param project_uid: str (required), path. 
        :param template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: JobPartsDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/applyTemplate/{template_uid}/assignProviders"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return JobPartsDto(**r.json())
        


    async def assign_linguists_from_template_to_job_parts(
        self,
        job_part_references: JobPartReferences,
        project_uid: str,
        template_uid: str,
        phrase_token: Optional[str] = None,
) -> JobPartsDto:
        """
        Operation id: assignLinguistsFromTemplateToJobParts
        Assigns providers from template (specific jobs)
        
        :param job_part_references: JobPartReferences (required), body. 
        :param project_uid: str (required), path. 
        :param template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: JobPartsDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/applyTemplate/{template_uid}/assignProviders/forJobParts"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = job_part_references

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return JobPartsDto(**r.json())
        


    async def assignable_templates(
        self,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> AssignableTemplatesDto:
        """
        Operation id: assignableTemplates
        List assignable templates
        
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AssignableTemplatesDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/assignableTemplates"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return AssignableTemplatesDto(**r.json())
        


    async def create_custom_fields_on_project_template(
        self,
        create_custom_field_instances_dto: CreateCustomFieldInstancesDto,
        project_template_uid: str,
        phrase_token: Optional[str] = None,
) -> CustomFieldInstancesDto:
        """
        Operation id: createCustomFieldsOnProjectTemplate
        Create custom field instances
        
        :param create_custom_field_instances_dto: CreateCustomFieldInstancesDto (required), body. 
        :param project_template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: CustomFieldInstancesDto
        """
        endpoint = f"/api2/v1/projectTemplates/{project_template_uid}/customFields"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = create_custom_field_instances_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return CustomFieldInstancesDto(**r.json())
        


    async def create_project_from_template_v2(
        self,
        create_project_from_template_v2_dto: CreateProjectFromTemplateV2Dto,
        template_uid: str,
        phrase_token: Optional[str] = None,
) -> AbstractProjectDtoV2:
        """
        Operation id: createProjectFromTemplateV2
        Create project from template
        
        :param create_project_from_template_v2_dto: CreateProjectFromTemplateV2Dto (required), body. 
        :param template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AbstractProjectDtoV2
        """
        endpoint = f"/api2/v2/projects/applyTemplate/{template_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = create_project_from_template_v2_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return AbstractProjectDtoV2(**r.json())
        


    async def create_project_from_template_v2_async(
        self,
        create_project_from_template_async_v2_dto: CreateProjectFromTemplateAsyncV2Dto,
        template_uid: str,
        phrase_token: Optional[str] = None,
) -> AsyncRequestWrapperV2Dto:
        """
        Operation id: createProjectFromTemplateV2Async
        Create project from template (async)
        
        :param create_project_from_template_async_v2_dto: CreateProjectFromTemplateAsyncV2Dto (required), body. 
        :param template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AsyncRequestWrapperV2Dto
        """
        endpoint = f"/api2/v2/projects/applyTemplate/async/{template_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = create_project_from_template_async_v2_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return AsyncRequestWrapperV2Dto(**r.json())
        


    async def create_project_template(
        self,
        project_template_create_action_dto: ProjectTemplateCreateActionDto,
        phrase_token: Optional[str] = None,
) -> ProjectTemplate:
        """
        Operation id: createProjectTemplate
        Create project template
        
        :param project_template_create_action_dto: ProjectTemplateCreateActionDto (required), body. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ProjectTemplate
        """
        endpoint = f"/api2/v1/projectTemplates"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = project_template_create_action_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ProjectTemplate(**r.json())
        


    async def delete_custom_field_of_project_template(
        self,
        field_instance_uid: str,
        project_template_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: deleteCustomFieldOfProjectTemplate
        Delete custom field of project template
        
        :param field_instance_uid: str (required), path. 
        :param project_template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/projectTemplates/{project_template_uid}/customFields/{field_instance_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "DELETE",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    async def delete_project_template(
        self,
        project_template_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: deleteProjectTemplate
        Delete project template
        
        :param project_template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/projectTemplates/{project_template_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "DELETE",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    async def edit_custom_field_on_project_template(
        self,
        update_custom_field_instance_dto: UpdateCustomFieldInstanceDto,
        field_instance_uid: str,
        project_template_uid: str,
        phrase_token: Optional[str] = None,
) -> CustomFieldInstanceDto:
        """
        Operation id: editCustomFieldOnProjectTemplate
        Edit custom field of project template
        
        :param update_custom_field_instance_dto: UpdateCustomFieldInstanceDto (required), body. 
        :param field_instance_uid: str (required), path. 
        :param project_template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: CustomFieldInstanceDto
        """
        endpoint = f"/api2/v1/projectTemplates/{project_template_uid}/customFields/{field_instance_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = update_custom_field_instance_dto

        r = await self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return CustomFieldInstanceDto(**r.json())
        


    async def edit_custom_fields_on_project_template(
        self,
        update_custom_field_instances_dto: UpdateCustomFieldInstancesDto,
        project_template_uid: str,
        phrase_token: Optional[str] = None,
) -> CustomFieldInstancesDto:
        """
        Operation id: editCustomFieldsOnProjectTemplate
        Edit custom fields of the project template (batch)
        
        :param update_custom_field_instances_dto: UpdateCustomFieldInstancesDto (required), body. 
        :param project_template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: CustomFieldInstancesDto
        """
        endpoint = f"/api2/v1/projectTemplates/{project_template_uid}/customFields"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = update_custom_field_instances_dto

        r = await self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return CustomFieldInstancesDto(**r.json())
        


    async def edit_project_template(
        self,
        project_template_edit_dto: ProjectTemplateEditDto,
        project_template_uid: str,
        phrase_token: Optional[str] = None,
) -> ProjectTemplate:
        """
        Operation id: editProjectTemplate
        Edit project template
        
        :param project_template_edit_dto: ProjectTemplateEditDto (required), body. 
        :param project_template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ProjectTemplate
        """
        endpoint = f"/api2/v1/projectTemplates/{project_template_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = project_template_edit_dto

        r = await self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ProjectTemplate(**r.json())
        


    async def edit_project_template_access_settings(
        self,
        edit_project_security_settings_dto_v2: EditProjectSecuritySettingsDtoV2,
        project_template_uid: str,
        phrase_token: Optional[str] = None,
) -> ProjectSecuritySettingsDtoV2:
        """
        Operation id: editProjectTemplateAccessSettings
        Edit project template access and security settings
        
        :param edit_project_security_settings_dto_v2: EditProjectSecuritySettingsDtoV2 (required), body. 
        :param project_template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ProjectSecuritySettingsDtoV2
        """
        endpoint = f"/api2/v1/projectTemplates/{project_template_uid}/accessSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = edit_project_security_settings_dto_v2

        r = await self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ProjectSecuritySettingsDtoV2(**r.json())
        


    async def edit_project_template_import_settings(
        self,
        file_import_settings_create_dto: FileImportSettingsCreateDto,
        project_template_uid: str,
        phrase_token: Optional[str] = None,
) -> FileImportSettingsDto:
        """
        Operation id: editProjectTemplateImportSettings
        Edit project template import settings
        
        :param file_import_settings_create_dto: FileImportSettingsCreateDto (required), body. 
        :param project_template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: FileImportSettingsDto
        """
        endpoint = f"/api2/v1/projectTemplates/{project_template_uid}/importSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = file_import_settings_create_dto

        r = await self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return FileImportSettingsDto(**r.json())
        


    async def edit_project_template_v2(
        self,
        project_template_edit_v2_dto: ProjectTemplateEditV2Dto,
        project_template_uid: str,
        phrase_token: Optional[str] = None,
) -> ProjectTemplate:
        """
        Operation id: editProjectTemplateV2
        Edit project template
        
        :param project_template_edit_v2_dto: ProjectTemplateEditV2Dto (required), body. 
        :param project_template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ProjectTemplate
        """
        endpoint = f"/api2/v2/projectTemplates/{project_template_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = project_template_edit_v2_dto

        r = await self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ProjectTemplate(**r.json())
        


    async def get_analyse_settings_for_project_template(
        self,
        project_template_uid: str,
        phrase_token: Optional[str] = None,
) -> AbstractAnalyseSettingsDto:
        """
        Operation id: getAnalyseSettingsForProjectTemplate
        Get analyse settings
        
        :param project_template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AbstractAnalyseSettingsDto
        """
        endpoint = f"/api2/v1/projectTemplates/{project_template_uid}/analyseSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return AbstractAnalyseSettingsDto(**r.json())
        


    async def get_custom_field_of_project_template(
        self,
        field_instance_uid: str,
        project_template_uid: str,
        phrase_token: Optional[str] = None,
) -> CustomFieldInstanceDto:
        """
        Operation id: getCustomFieldOfProjectTemplate
        Get custom field of project template
        
        :param field_instance_uid: str (required), path. 
        :param project_template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: CustomFieldInstanceDto
        """
        endpoint = f"/api2/v1/projectTemplates/{project_template_uid}/customFields/{field_instance_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return CustomFieldInstanceDto(**r.json())
        


    async def get_custom_fields_page_of_project_template(
        self,
        project_template_uid: str,
        created_by: Optional[List[str]] = None,
        modified_by: Optional[List[str]] = None,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 20,
        sort_field: Optional[str] = None,
        sort_trend: Optional[str] = "ASC",
        phrase_token: Optional[str] = None,
) -> PageDtoCustomFieldInstanceDto:
        """
        Operation id: getCustomFieldsPageOfProjectTemplate
        Get custom fields of project template (page)
        
        :param project_template_uid: str (required), path. 
        :param created_by: Optional[List[str]] = None (optional), query. Filter by webhook creators UIDs.
        :param modified_by: Optional[List[str]] = None (optional), query. Filter by webhook updaters UIDs.
        :param page_number: Optional[int] = 0 (optional), query. Page number, starting with 0, default 0.
        :param page_size: Optional[int] = 20 (optional), query. Page size, accepts values between 1 and 50, default 20.
        :param sort_field: Optional[str] = None (optional), query. Sort by this field.
        :param sort_trend: Optional[str] = "ASC" (optional), query. Sort direction.
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoCustomFieldInstanceDto
        """
        endpoint = f"/api2/v1/projectTemplates/{project_template_uid}/customFields"
        params = {
            "pageNumber": page_number,
            "pageSize": page_size,
            "createdBy": created_by,
            "modifiedBy": modified_by,
            "sortField": sort_field,
            "sortTrend": sort_trend
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoCustomFieldInstanceDto(**r.json())
        


    async def get_import_settings_for_project_template(
        self,
        project_template_uid: str,
        phrase_token: Optional[str] = None,
) -> FileImportSettingsDto:
        """
        Operation id: getImportSettingsForProjectTemplate
        Get import settings
        
        :param project_template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: FileImportSettingsDto
        """
        endpoint = f"/api2/v1/projectTemplates/{project_template_uid}/importSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return FileImportSettingsDto(**r.json())
        


    async def get_machine_translate_settings_for_project_template(
        self,
        project_template_uid: str,
        phrase_token: Optional[str] = None,
) -> MTSettingsPerLanguageListDto:
        """
        Operation id: getMachineTranslateSettingsForProjectTemplate
        Get project template machine translate settings
        
        :param project_template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: MTSettingsPerLanguageListDto
        """
        endpoint = f"/api2/v1/projectTemplates/{project_template_uid}/mtSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return MTSettingsPerLanguageListDto(**r.json())
        


    async def get_project_template(
        self,
        project_template_uid: str,
        phrase_token: Optional[str] = None,
) -> ProjectTemplate:
        """
        Operation id: getProjectTemplate
        Get project template
        Note: importSettings in response is deprecated and will be always null
        :param project_template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ProjectTemplate
        """
        endpoint = f"/api2/v1/projectTemplates/{project_template_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ProjectTemplate(**r.json())
        


    async def get_project_template_access_settings(
        self,
        project_template_uid: str,
        phrase_token: Optional[str] = None,
) -> ProjectSecuritySettingsDtoV2:
        """
        Operation id: getProjectTemplateAccessSettings
        Get project template access and security settings
        
        :param project_template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ProjectSecuritySettingsDtoV2
        """
        endpoint = f"/api2/v1/projectTemplates/{project_template_uid}/accessSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ProjectSecuritySettingsDtoV2(**r.json())
        


    async def get_project_template_pre_translate_settings_v4(
        self,
        project_template_uid: str,
        phrase_token: Optional[str] = None,
) -> PreTranslateSettingsV4Dto:
        """
        Operation id: getProjectTemplatePreTranslateSettingsV4
        Get project template pre-translate settings
        
        :param project_template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PreTranslateSettingsV4Dto
        """
        endpoint = f"/api2/v4/projectTemplates/{project_template_uid}/preTranslateSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PreTranslateSettingsV4Dto(**r.json())
        


    async def get_project_template_qa_settings(
        self,
        project_template_uid: str,
        phrase_token: Optional[str] = None,
) -> QASettingsDtoV2:
        """
        Operation id: getProjectTemplateQASettings
        Get quality assurance settings
        
        :param project_template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: QASettingsDtoV2
        """
        endpoint = f"/api2/v1/projectTemplates/{project_template_uid}/qaSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return QASettingsDtoV2(**r.json())
        


    async def get_project_template_term_bases(
        self,
        project_template_uid: str,
        phrase_token: Optional[str] = None,
) -> ProjectTemplateTermBaseListDto:
        """
        Operation id: getProjectTemplateTermBases
        Get term bases
        
        :param project_template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ProjectTemplateTermBaseListDto
        """
        endpoint = f"/api2/v1/projectTemplates/{project_template_uid}/termBases"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ProjectTemplateTermBaseListDto(**r.json())
        


    async def get_project_template_trans_memories_2(
        self,
        project_template_uid: str,
        target_lang: Optional[str] = None,
        wf_step_uid: Optional[str] = None,
        phrase_token: Optional[str] = None,
) -> ProjectTemplateTransMemoryListDtoV3:
        """
        Operation id: getProjectTemplateTransMemories_2
        Get translation memories
        
        :param project_template_uid: str (required), path. 
        :param target_lang: Optional[str] = None (optional), query. Filter project translation memories by target language.
        :param wf_step_uid: Optional[str] = None (optional), query. Filter project translation memories by workflow step.
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ProjectTemplateTransMemoryListDtoV3
        """
        endpoint = f"/api2/v3/projectTemplates/{project_template_uid}/transMemories"
        params = {
            "targetLang": target_lang,
            "wfStepUid": wf_step_uid
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ProjectTemplateTransMemoryListDtoV3(**r.json())
        


    async def get_project_templates(
        self,
        business_unit_name: Optional[str] = None,
        client_id: Optional[int] = None,
        client_name: Optional[str] = None,
        cost_center_id: Optional[int] = None,
        cost_center_name: Optional[str] = None,
        created_by_uid: Optional[str] = None,
        created_in_last_hours: Optional[int] = None,
        direction: Optional[str] = "desc",
        domain_name: Optional[str] = None,
        name: Optional[str] = None,
        owner_uid: Optional[str] = None,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 50,
        sort: Optional[str] = "dateCreated",
        source_langs: Optional[List[str]] = None,
        sub_domain_name: Optional[str] = None,
        target_langs: Optional[List[str]] = None,
        phrase_token: Optional[str] = None,
) -> PageDtoProjectTemplateReference:
        """
        Operation id: getProjectTemplates
        List project templates
        
API call to list [project templates](https://support.phrase.com/hc/en-us/articles/5709647439772-Project-Templates-TMS-).

Use the query parameters below to refine your search criteria for project templates:

- **name** - The full project template name or a portion of it. For example, using `name=GUI` or `name=02`
will locate project templates named `GUI02`.
- **clientId** - The client's ID within the system, not interchangeable with its UID.
- **clientName** - The complete or partial name of the client. For instance, using `clientName=GUI` or `clientName=02`
will find project templates associated with the client `GUI02`.
- **ownerUid** - The user UID who owns the project template within the system, interchangeable with its ID.
- **domainName** - The complete or partial name of the domain. Using `domainName=GUI` or `domainName=02` will find
project templates associated with the domain `GUI02`.
- **subDomainName** - The complete or partial name of the subdomain. For instance, using `subDomainName=GUI` or
`subDomainName=02` will locate project templates linked to the subdomain `GUI02`.
- **costCenterId** - The cost center's ID within the system, not interchangeable with its UID.
- **costCenterName** - The complete or partial name of the cost center. For example, using `costCenterName=GUI` or
`costCenterName=02` will find project templates associated with the cost center `GUI02`.
- **businessUnitName** - The complete or partial name of the business unit. For instance, using `businessUnitName=GUI`
or `businessUnitName=02` will locate project templates linked to the business unit `GUI02`.
- **sort** - Determines if the resulting list of project templates should be sorted by their names or the date they
were created. This field supports either `dateCreated` or `templateName` as values.
- **direction** - Indicates the sorting order for the resulting list by using either `asc` (ascending) or `desc`
(descending) values.
- **pageNumber** - Indicates the desired page number (zero-based) to retrieve. The total number of pages is returned in
the `totalPages` field within each response.
- **pageSize** - Indicates the page size, affecting the `totalPages` retrieved in each response and potentially
impacting the number of iterations needed to obtain all project templates.

        :param business_unit_name: Optional[str] = None (optional), query. 
        :param client_id: Optional[int] = None (optional), query. 
        :param client_name: Optional[str] = None (optional), query. 
        :param cost_center_id: Optional[int] = None (optional), query. 
        :param cost_center_name: Optional[str] = None (optional), query. 
        :param created_by_uid: Optional[str] = None (optional), query. 
        :param created_in_last_hours: Optional[int] = None (optional), query. 
        :param direction: Optional[str] = "desc" (optional), query. 
        :param domain_name: Optional[str] = None (optional), query. 
        :param name: Optional[str] = None (optional), query. 
        :param owner_uid: Optional[str] = None (optional), query. 
        :param page_number: Optional[int] = 0 (optional), query. Page number, starting with 0, default 0.
        :param page_size: Optional[int] = 50 (optional), query. Page size, accepts values between 1 and 50, default 50.
        :param sort: Optional[str] = "dateCreated" (optional), query. 
        :param source_langs: Optional[List[str]] = None (optional), query. 
        :param sub_domain_name: Optional[str] = None (optional), query. 
        :param target_langs: Optional[List[str]] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoProjectTemplateReference
        """
        endpoint = f"/api2/v1/projectTemplates"
        params = {
            "name": name,
            "clientId": client_id,
            "clientName": client_name,
            "ownerUid": owner_uid,
            "createdByUid": created_by_uid,
            "domainName": domain_name,
            "subDomainName": sub_domain_name,
            "costCenterId": cost_center_id,
            "costCenterName": cost_center_name,
            "businessUnitName": business_unit_name,
            "sourceLangs": source_langs,
            "targetLangs": target_langs,
            "createdInLastHours": created_in_last_hours,
            "sort": sort,
            "direction": direction,
            "pageNumber": page_number,
            "pageSize": page_size
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoProjectTemplateReference(**r.json())
        


    async def relevant_trans_memories_for_project_template(
        self,
        project_template_uid: str,
        client_name: Optional[str] = None,
        domain_name: Optional[str] = None,
        name: Optional[str] = None,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 50,
        strict_lang_matching: Optional[bool] = False,
        sub_domain_name: Optional[str] = None,
        target_langs: Optional[List[str]] = None,
        phrase_token: Optional[str] = None,
) -> PageDtoTransMemoryDto:
        """
        Operation id: relevantTransMemoriesForProjectTemplate
        List project template relevant translation memories
        
        :param project_template_uid: str (required), path. 
        :param client_name: Optional[str] = None (optional), query. 
        :param domain_name: Optional[str] = None (optional), query. 
        :param name: Optional[str] = None (optional), query. 
        :param page_number: Optional[int] = 0 (optional), query. Page number, starting with 0, default 0.
        :param page_size: Optional[int] = 50 (optional), query. Page size, accepts values between 1 and 50, default 50.
        :param strict_lang_matching: Optional[bool] = False (optional), query. 
        :param sub_domain_name: Optional[str] = None (optional), query. 
        :param target_langs: Optional[List[str]] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoTransMemoryDto
        """
        endpoint = f"/api2/v1/projectTemplates/{project_template_uid}/transMemories/relevant"
        params = {
            "name": name,
            "domainName": domain_name,
            "clientName": client_name,
            "subDomainName": sub_domain_name,
            "targetLangs": target_langs,
            "strictLangMatching": strict_lang_matching,
            "pageNumber": page_number,
            "pageSize": page_size
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoTransMemoryDto(**r.json())
        


    async def set_project_template_qa_settings(
        self,
        edit_qa_settings_dto_v2: EditQASettingsDtoV2,
        project_template_uid: str,
        phrase_token: Optional[str] = None,
) -> QASettingsDtoV2:
        """
        Operation id: setProjectTemplateQASettings
        Edit quality assurance settings
        
        :param edit_qa_settings_dto_v2: EditQASettingsDtoV2 (required), body. 
        :param project_template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: QASettingsDtoV2
        """
        endpoint = f"/api2/v1/projectTemplates/{project_template_uid}/qaSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = edit_qa_settings_dto_v2

        r = await self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return QASettingsDtoV2(**r.json())
        


    async def set_project_template_term_bases(
        self,
        set_project_template_term_base_dto: SetProjectTemplateTermBaseDto,
        project_template_uid: str,
        phrase_token: Optional[str] = None,
) -> ProjectTemplateTermBaseListDto:
        """
        Operation id: setProjectTemplateTermBases
        Edit term bases in project template
        
        :param set_project_template_term_base_dto: SetProjectTemplateTermBaseDto (required), body. 
        :param project_template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ProjectTemplateTermBaseListDto
        """
        endpoint = f"/api2/v1/projectTemplates/{project_template_uid}/termBases"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = set_project_template_term_base_dto

        r = await self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ProjectTemplateTermBaseListDto(**r.json())
        


    async def set_project_template_trans_memories_v2(
        self,
        set_project_template_trans_memories_v2_dto: SetProjectTemplateTransMemoriesV2Dto,
        project_template_uid: str,
        phrase_token: Optional[str] = None,
) -> ProjectTemplateTransMemoryListV2Dto:
        """
        Operation id: setProjectTemplateTransMemoriesV2
        Edit translation memories
        If user wants to edit “All target languages” or "All workflow steps”, 
                       but there are already varied TM settings for individual languages or steps, 
                       then the user risks to overwrite these individual choices.
        :param set_project_template_trans_memories_v2_dto: SetProjectTemplateTransMemoriesV2Dto (required), body. 
        :param project_template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: ProjectTemplateTransMemoryListV2Dto
        """
        endpoint = f"/api2/v2/projectTemplates/{project_template_uid}/transMemories"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = set_project_template_trans_memories_v2_dto

        r = await self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return ProjectTemplateTransMemoryListV2Dto(**r.json())
        


    async def update_analyse_settings_for_project_template(
        self,
        edit_analyse_settings_dto: EditAnalyseSettingsDto,
        project_template_uid: str,
        phrase_token: Optional[str] = None,
) -> AbstractAnalyseSettingsDto:
        """
        Operation id: updateAnalyseSettingsForProjectTemplate
        Edit analyse settings
        
        :param edit_analyse_settings_dto: EditAnalyseSettingsDto (required), body. 
        :param project_template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AbstractAnalyseSettingsDto
        """
        endpoint = f"/api2/v1/projectTemplates/{project_template_uid}/analyseSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = edit_analyse_settings_dto

        r = await self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return AbstractAnalyseSettingsDto(**r.json())
        


    async def update_project_template_pre_translate_settings_v4(
        self,
        pre_translate_settings_v4_dto: PreTranslateSettingsV4Dto,
        project_template_uid: str,
        phrase_token: Optional[str] = None,
) -> PreTranslateSettingsV4Dto:
        """
        Operation id: updateProjectTemplatePreTranslateSettingsV4
        Update project template pre-translate settings
        
        :param pre_translate_settings_v4_dto: PreTranslateSettingsV4Dto (required), body. 
        :param project_template_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PreTranslateSettingsV4Dto
        """
        endpoint = f"/api2/v4/projectTemplates/{project_template_uid}/preTranslateSettings"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = pre_translate_settings_v4_dto

        r = await self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PreTranslateSettingsV4Dto(**r.json())
        



if __name__ == '__main__':
    print("This module is not intended to be run directly.")


from __future__ import annotations

from datetime import datetime
from typing import TYPE_CHECKING, List, Optional, Union, Any

if TYPE_CHECKING:
    from ..client import SyncPhraseTMSClient

from ..models import (
    RemoteUploadedFileDto,
    UploadedFileDto,
    PageDtoUploadedFileDto
    
)


class FileOperations:
    def __init__(self, client: SyncPhraseTMSClient):
        self.client = client


    async def create_url_file(
        self,
        content_disposition: str,
        remote_uploaded_file_dto: RemoteUploadedFileDto,
        phrase_token: Optional[str] = None,
) -> UploadedFileDto:
        """
        Operation id: createUrlFile
        Upload file
        Accepts multipart/form-data, application/octet-stream or application/json.
        :param content_disposition: str (required), header. must match pattern `((inline|attachment); )?filename\*=UTF-8''(.+)`.
        :param remote_uploaded_file_dto: RemoteUploadedFileDto (required), body. file.
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: UploadedFileDto
        """
        endpoint = f"/api2/v1/files"
        params = {
            
        }
        headers = {
            "Content-Disposition": content_disposition
            
        }

        content = None

        files = None

        payload = remote_uploaded_file_dto

        r = await self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return UploadedFileDto(**r.json())
        


    async def deletes_file(
        self,
        file_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: deletesFile
        Delete file
        
        :param file_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/files/{file_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "DELETE",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    async def get_file_json(
        self,
        file_uid: str,
        phrase_token: Optional[str] = None,
) -> UploadedFileDto:
        """
        Operation id: getFileJson
        Get file
        Get uploaded file as <b>octet-stream</b> or as <b>json</b> based on 'Accept' header
        :param file_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: UploadedFileDto
        """
        endpoint = f"/api2/v1/files/{file_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return UploadedFileDto(**r.json())
        


    async def get_files(
        self,
        bigger_than: Optional[int] = None,
        created_by: Optional[int] = None,
        name: Optional[str] = None,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 50,
        types: Optional[List[str]] = None,
        phrase_token: Optional[str] = None,
) -> PageDtoUploadedFileDto:
        """
        Operation id: getFiles
        List files
        
        :param bigger_than: Optional[int] = None (optional), query. Size in bytes.
        :param created_by: Optional[int] = None (optional), query. 
        :param name: Optional[str] = None (optional), query. 
        :param page_number: Optional[int] = 0 (optional), query. Page number, starting with 0, default 0.
        :param page_size: Optional[int] = 50 (optional), query. Page size, accepts values between 1 and 50, default 50.
        :param types: Optional[List[str]] = None (optional), query. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoUploadedFileDto
        """
        endpoint = f"/api2/v1/files"
        params = {
            "pageNumber": page_number,
            "pageSize": page_size,
            "name": name,
            "types": types,
            "createdBy": created_by,
            "biggerThan": bigger_than
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoUploadedFileDto(**r.json())
        



if __name__ == '__main__':
    print("This module is not intended to be run directly.")


import logging
from typing import Optional, TypeVar, Dict

import httpx
from httpx import HTTPStatusError
from httpx._types import RequestFiles
from pydantic import BaseModel

from .exceptions import PhrappyError
from .async_tags import (
    AdditionalWorkflowStepOperations,
    AnalysisOperations,
    AsyncRequestOperations,
    AuthenticationOperations,
    BilingualFileOperations,
    BusinessUnitOperations,
    BuyerOperations,
    ClientOperations,
    ConnectorOperations,
    CostCenterOperations,
    CustomFieldsOperations,
    CustomFileTypeOperations,
    DomainOperations,
    EmailTemplateOperations,
    FileOperations,
    GlossaryOperations,
    ImportsettingsOperations,
    ConversationsOperations,
    SupportedLanguagesOperations,
    LanguageQualityAssessmentOperations,
    QualityAssuranceOperations,
    MachineTranslationSettingsOperations,
    MachineTranslationOperations,
    MappingOperations,
    LanguageAIOperations,
    NetRateSchemeOperations,
    NotificationsOperations,
    PriceListOperations,
    ProjectTemplateOperations,
    TermBaseOperations,
    TranslationMemoryOperations,
    ProjectOperations,
    JobOperations,
    TranslationOperations,
    SegmentOperations,
    ProviderOperations,
    ProjectReferenceFileOperations,
    QuoteOperations,
    SCIMOperations,
    SegmentationRulesOperations,
    SpellCheckOperations,
    SubDomainOperations,
    UserOperations,
    WorkflowStepOperations,
    VendorOperations,
    WebhookOperations,
    XMLAssistantOperations,
    WorkflowchangesOperations
    
)


MEMSOURCE_BASE_URL = "https://cloud.memsource.com/web"

logger = logging.getLogger(__name__)

T = TypeVar('T', bound=BaseModel)


class AsyncPhrappy:
    def __init__(self, token: Optional[str] = None):
        def _token_validation(token) -> str | None:
            if token and token.startswith("ApiToken "):
                return token
            elif token:
                return "ApiToken " + token
            else:
                return
        self.token = _token_validation(token)
        self.additional_workflow_step = AdditionalWorkflowStepOperations(self)
        self.analysis = AnalysisOperations(self)
        self.async_request = AsyncRequestOperations(self)
        self.authentication = AuthenticationOperations(self)
        self.bilingual_file = BilingualFileOperations(self)
        self.business_unit = BusinessUnitOperations(self)
        self.buyer = BuyerOperations(self)
        self.client = ClientOperations(self)
        self.connector = ConnectorOperations(self)
        self.cost_center = CostCenterOperations(self)
        self.custom_fields = CustomFieldsOperations(self)
        self.custom_file_type = CustomFileTypeOperations(self)
        self.domain = DomainOperations(self)
        self.email_template = EmailTemplateOperations(self)
        self.file = FileOperations(self)
        self.glossary = GlossaryOperations(self)
        self.importsettings = ImportsettingsOperations(self)
        self.conversations = ConversationsOperations(self)
        self.supported_languages = SupportedLanguagesOperations(self)
        self.language_quality_assessment = LanguageQualityAssessmentOperations(self)
        self.quality_assurance = QualityAssuranceOperations(self)
        self.machine_translation_settings = MachineTranslationSettingsOperations(self)
        self.machine_translation = MachineTranslationOperations(self)
        self.mapping = MappingOperations(self)
        self.language_ai = LanguageAIOperations(self)
        self.net_rate_scheme = NetRateSchemeOperations(self)
        self.notifications = NotificationsOperations(self)
        self.price_list = PriceListOperations(self)
        self.project_template = ProjectTemplateOperations(self)
        self.term_base = TermBaseOperations(self)
        self.translation_memory = TranslationMemoryOperations(self)
        self.project = ProjectOperations(self)
        self.job = JobOperations(self)
        self.translation = TranslationOperations(self)
        self.segment = SegmentOperations(self)
        self.provider = ProviderOperations(self)
        self.project_reference_file = ProjectReferenceFileOperations(self)
        self.quote = QuoteOperations(self)
        self.scim = SCIMOperations(self)
        self.segmentation_rules = SegmentationRulesOperations(self)
        self.spell_check = SpellCheckOperations(self)
        self.sub_domain = SubDomainOperations(self)
        self.user = UserOperations(self)
        self.workflow_step = WorkflowStepOperations(self)
        self.vendor = VendorOperations(self)
        self.webhook = WebhookOperations(self)
        self.xml_assistant = XMLAssistantOperations(self)
        self.workflowchanges = WorkflowchangesOperations(self)
        

    async def make_request(
        self,
        method: str,
        path: str,
        phrase_token: Optional[str] = None,
        params: Optional[dict] = None,
        payload: Optional[T | Dict] = None,
        files: Optional[RequestFiles] = None,
        headers: Optional[dict] = None,
        content: Optional[bytes] = None,
        timeout: float = 180.0
    ) -> httpx.Response:
        token = phrase_token or self.token

        url = f"{MEMSOURCE_BASE_URL}{path}"
        header = {}

        if token:
            header["Authorization"] = token
        if headers is not None:
            header.update(headers)

        if payload is not None and not isinstance(payload, dict):
            try:
                payload = payload.model_dump(exclude_unset=True)
            except Exception as e:
                logger.exception(f"Payload could not be cast as dict: {e}")
                raise Exception from e

        if params is not None:
            remove = []
            for k, v in params.items():
                if v is None:
                    remove.append(k)
            if remove:
                for k in remove:
                    params.pop(k)
        async with httpx.AsyncClient() as client:
            r = await client.request(
                method=method,
                url=url,
                headers=header,
                params=params,
                json=payload,
                files=files,
                content=content,
                timeout=timeout,
            )

        try:
            r.raise_for_status()
        except HTTPStatusError as exc:
            try:
                loaded_errors = r.json()
                error_code = loaded_errors.get("errorCode")
                error_detail = loaded_errors.get("errorDescription")
                msg = f"Call failed: {method=} {url=}, {r.request.content=}, {r.status_code=}, {error_code=}, {error_detail=}"
                raise PhrappyError(msg)
            except:
                logger.exception(f"Call failed: {r} // {url=} - {r.request.content=}")
                raise Exception from exc
        else:
            return r

    @classmethod
    async def from_creds(cls, username: str, password: str) -> 'Phrappy':
        pp = cls()
        login_dto = {"userName": username, "password": password}
        resp = await pp.authentication.login(login_dto)
        return cls(resp.token)



from __future__ import annotations

from datetime import datetime
from typing import TYPE_CHECKING, List, Optional, Union, Any

if TYPE_CHECKING:
    from ..client import SyncPhraseTMSClient

from ..models import (
    PageDtoCustomFieldOptionDto,
    UpdateCustomFieldDto,
    PageDtoCustomFieldDto,
    CreateCustomFieldDto,
    CustomFieldDto
    
)


class CustomFieldsOperations:
    def __init__(self, client: SyncPhraseTMSClient):
        self.client = client


    def create_custom_field(
        self,
        create_custom_field_dto: CreateCustomFieldDto,
        phrase_token: Optional[str] = None,
) -> CustomFieldDto:
        """
        Operation id: createCustomField
        Create custom field
        
        :param create_custom_field_dto: CreateCustomFieldDto (required), body. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: CustomFieldDto
        """
        endpoint = f"/api2/v1/customFields"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = create_custom_field_dto

        r = self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return CustomFieldDto(**r.json())
        


    def delete_custom_field(
        self,
        field_uid: str,
        phrase_token: Optional[str] = None,
) -> None:
        """
        Operation id: deleteCustomField
        Delete custom field
        
        :param field_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: None
        """
        endpoint = f"/api2/v1/customFields/{field_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "DELETE",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return
        


    def get_custom_field(
        self,
        field_uid: str,
        phrase_token: Optional[str] = None,
) -> CustomFieldDto:
        """
        Operation id: getCustomField
        Get custom field
        
        :param field_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: CustomFieldDto
        """
        endpoint = f"/api2/v1/customFields/{field_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return CustomFieldDto(**r.json())
        


    def get_custom_field_list(
        self,
        allowed_entities: Optional[List[str]] = None,
        created_by: Optional[List[str]] = None,
        modified_by: Optional[List[str]] = None,
        name: Optional[str] = None,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 50,
        required: Optional[bool] = None,
        sort_field: Optional[str] = None,
        sort_trend: Optional[str] = "ASC",
        types: Optional[List[str]] = None,
        uids: Optional[List[str]] = None,
        phrase_token: Optional[str] = None,
) -> PageDtoCustomFieldDto:
        """
        Operation id: getCustomFieldList
        Lists custom fields
        
        :param allowed_entities: Optional[List[str]] = None (optional), query. Filter by custom field allowed entities.
        :param created_by: Optional[List[str]] = None (optional), query. Filter by custom field creators UIDs.
        :param modified_by: Optional[List[str]] = None (optional), query. Filter by custom field updaters UIDs.
        :param name: Optional[str] = None (optional), query. Filter by custom field name.
        :param page_number: Optional[int] = 0 (optional), query. Page number, starting with 0, default 0.
        :param page_size: Optional[int] = 50 (optional), query. Page size, accepts values between 1 and 50, default 50.
        :param required: Optional[bool] = None (optional), query. Filter by custom field required parameter.
        :param sort_field: Optional[str] = None (optional), query. Sort by this field.
        :param sort_trend: Optional[str] = "ASC" (optional), query. Sort direction.
        :param types: Optional[List[str]] = None (optional), query. Filter by custom field types.
        :param uids: Optional[List[str]] = None (optional), query. Filter by custom field UIDs.
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoCustomFieldDto
        """
        endpoint = f"/api2/v1/customFields"
        params = {
            "pageNumber": page_number,
            "pageSize": page_size,
            "name": name,
            "allowedEntities": allowed_entities,
            "types": types,
            "createdBy": created_by,
            "modifiedBy": modified_by,
            "uids": uids,
            "required": required,
            "sortField": sort_field,
            "sortTrend": sort_trend
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoCustomFieldDto(**r.json())
        


    def get_custom_field_option_list(
        self,
        field_uid: str,
        name: Optional[str] = None,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 50,
        sort_field: Optional[str] = "NAME",
        sort_trend: Optional[str] = "ASC",
        phrase_token: Optional[str] = None,
) -> PageDtoCustomFieldOptionDto:
        """
        Operation id: getCustomFieldOptionList
        Lists options of custom field
        
        :param field_uid: str (required), path. 
        :param name: Optional[str] = None (optional), query. Filter by option name.
        :param page_number: Optional[int] = 0 (optional), query. Page number, starting with 0, default 0.
        :param page_size: Optional[int] = 50 (optional), query. Page size, accepts values between 1 and 50, default 50.
        :param sort_field: Optional[str] = "NAME" (optional), query. Sort by this field.
        :param sort_trend: Optional[str] = "ASC" (optional), query. Sort direction.
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageDtoCustomFieldOptionDto
        """
        endpoint = f"/api2/v1/customFields/{field_uid}/options"
        params = {
            "pageNumber": page_number,
            "pageSize": page_size,
            "name": name,
            "sortField": sort_field,
            "sortTrend": sort_trend
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageDtoCustomFieldOptionDto(**r.json())
        


    def update_custom_field(
        self,
        update_custom_field_dto: UpdateCustomFieldDto,
        field_uid: str,
        phrase_token: Optional[str] = None,
) -> CustomFieldDto:
        """
        Operation id: updateCustomField
        Edit custom field
        
        :param update_custom_field_dto: UpdateCustomFieldDto (required), body. 
        :param field_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: CustomFieldDto
        """
        endpoint = f"/api2/v1/customFields/{field_uid}"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = update_custom_field_dto

        r = self.client.make_request(
            "PUT",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return CustomFieldDto(**r.json())
        



if __name__ == '__main__':
    print("This module is not intended to be run directly.")


from __future__ import annotations

from datetime import datetime
from typing import TYPE_CHECKING, List, Optional, Union, Any

if TYPE_CHECKING:
    from ..client import SyncPhraseTMSClient

from ..models import (
    PageWithResponseTsDtoNotificationDto
    
)


class NotificationsOperations:
    def __init__(self, client: SyncPhraseTMSClient):
        self.client = client


    async def list_notifications_for_user(
        self,
        category: Optional[str] = None,
        created_after_date: Optional[str] = None,
        created_before_date: Optional[str] = None,
        page_number: Optional[int] = 0,
        page_size: Optional[int] = 20,
        phrase_token: Optional[str] = None,
) -> PageWithResponseTsDtoNotificationDto:
        """
        Operation id: listNotificationsForUser
        List notifications
        
        :param category: Optional[str] = None (optional), query. Filtered by notification category.
        :param created_after_date: Optional[str] = None (optional), query. Filtered by create date time in ISO 8601 UTC format.
        :param created_before_date: Optional[str] = None (optional), query. Filtered by create date time in ISO 8601 UTC format.
        :param page_number: Optional[int] = 0 (optional), query. Page number, starting with 0, default 0.
        :param page_size: Optional[int] = 20 (optional), query. Page size, accepts values between 1 and 50, default 20.
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: PageWithResponseTsDtoNotificationDto
        """
        endpoint = f"/api2/v1/notifications"
        params = {
            "pageNumber": page_number,
            "pageSize": page_size,
            "category": category,
            "createdBeforeDate": created_before_date,
            "createdAfterDate": created_after_date
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = None

        r = await self.client.make_request(
            "GET",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return PageWithResponseTsDtoNotificationDto(**r.json())
        



if __name__ == '__main__':
    print("This module is not intended to be run directly.")


from __future__ import annotations

import pprint
from datetime import datetime
from typing import TYPE_CHECKING, List, Optional, Union, Any

if TYPE_CHECKING:
    from ..client import SyncPhraseTMSClient

from ..models import (
    MachineTranslateResponse,
    TranslationRequestDto,
    AsyncRequestWrapperV2Dto,
    AsyncRequestWrapperDto,
    HumanTranslateJobsDto,
    PreTranslateJobsV3Dto
    
)


class TranslationOperations:
    def __init__(self, client: SyncPhraseTMSClient):
        self.client = client


    def human_translate(
        self,
        human_translate_jobs_dto: HumanTranslateJobsDto,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> AsyncRequestWrapperDto:
        """
        Operation id: humanTranslate
        Human translate (Gengo or Unbabel)
        
        :param human_translate_jobs_dto: HumanTranslateJobsDto (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AsyncRequestWrapperDto
        """
        endpoint = f"/api2/v1/projects/{project_uid}/jobs/humanTranslate"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = human_translate_jobs_dto

        r = self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return AsyncRequestWrapperDto(**r.json())
        


    def machine_translation_job(
        self,
        translation_request_dto: TranslationRequestDto,
        job_uid: str,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> MachineTranslateResponse:
        """
        Operation id: machineTranslationJob
        Translate using machine translation
        Configured machine translate settings is used
        :param translation_request_dto: TranslationRequestDto (required), body. 
        :param job_uid: str (required), path. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: MachineTranslateResponse
        """
        endpoint = f"/api2/v1/projects/{project_uid}/jobs/{job_uid}/translations/translateWithMachineTranslation"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = translation_request_dto

        r = self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )

        
        return MachineTranslateResponse(**r.json())
        


    def pre_translate_v3(
        self,
        pre_translate_jobs_v3_dto: PreTranslateJobsV3Dto,
        project_uid: str,
        phrase_token: Optional[str] = None,
) -> AsyncRequestWrapperV2Dto:
        """
        Operation id: preTranslateV3
        Pre-translate job
        
        :param pre_translate_jobs_v3_dto: PreTranslateJobsV3Dto (required), body. 
        :param project_uid: str (required), path. 
        
        :param phrase_token: string (optional) - if not supplied, client will look for token from init

        :return: AsyncRequestWrapperV2Dto
        """
        endpoint = f"/api2/v3/projects/{project_uid}/jobs/preTranslate"
        params = {
            
        }
        headers = {
            
        }

        content = None

        files = None

        payload = pre_translate_jobs_v3_dto

        r = self.client.make_request(
            "POST",
            endpoint,
            phrase_token,
            params=params,
            payload=payload,
            files=files,
            headers=headers,
            content=content
        )
        data = r.json()
        return AsyncRequestWrapperV2Dto(**data)
        



if __name__ == '__main__':
    print("This module is not intended to be run directly.")